#
# spec file for package checksec
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2013-2021 Fedora Project Authors
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           checksec
Version:        3.0.0
Release:        2.1
Summary:        Utility to check binaries for system hardening
License:        BSD-3-Clause
URL:            https://github.com/slimm609/checksec.sh
Source0:        https://github.com/slimm609/checksec.sh/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.bz2
BuildRequires:  golang-packaging
BuildRequires:  golang(API)

%description
Checksec is a GO program to check the properties of executables (like PIE,
RELRO, PaX, Canaries, ASLR, Fortify Source). It has been originally written by
Tobias Klein and the original source is available here:
http://www.trapkit.de/tools/checksec.html

Modern Linux distributions offer some mitigation techniques to make it harder
to exploit software vulnerabilities reliably. Mitigations such as RELRO,
NoExecute (NX), Stack Canaries, Address Space Layout Randomization (ASLR) and
Position Independent Executables (PIE) have made reliably exploiting any
vulnerabilities that do exist far more challenging. The checksec script is
designed to test what *standard* Linux OS and PaX (http://pax.grsecurity.net/)
security features are being used.

%prep
%autosetup -p 1
tar xf %SOURCE1

%build
mkdir build
cd build
go build -buildmode=pie ..

%install
cd build
mkdir -p %{buildroot}%{_bindir} %{buildroot}%{_mandir}/man1
install -pm 0755 %{name} %{buildroot}%{_bindir}
cd ..
install -pm 0644 extras/man/%{name}.1 %{buildroot}%{_mandir}/man1

%files
%license LICENSE
%doc ChangeLog README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Sun Mar  2 2025 Marcus Meissner <meissner@suse.com>
- build with pie
* Fri Feb 21 2025 Marcus Meissner <meissner@suse.com>
- updated to 3.0.0 release:
  - rewritten in go
* Thu May  9 2024 Dirk Müller <dmueller@suse.com>
- update to 2.7.1:
  * checksec FORTIFY detection (#236)
  * libc cleanup
  * Added github pages
  * Check kernel for YAMA
  * Fix Nx checks
  * Move github primary branch from master to main
  * Update gitattributes
  * Allow setting a libc file
  * Add tests for listfile
  * Fix trailing comma with listfile
  * Several shellcheck fixes
  * If no header is present, return N/A for Relro and nx
  * Remove superfluous -W flags
  * Fix broken Nx checks
  * change default libc search path from / to /lib
  * Cleanup grep
  * Rewrite man page in mdoc
  * Remove s_readelf
  * Fix stack protection and full relro check
  * Add tests suite for hardening checks
  * Speed up FS_comparison by 10x
  * Make shellcheck only run on final script
  * Fix debug exit check
  * Use Dynamic Section if there is no symbols table
  * Check foritfy vs fortified
* Sat Sep 24 2022 Dirk Müller <dmueller@suse.com>
- update to 2.6.0:
  * fix missing sysctl on fedora
  * remove extra parenthesis
  * add missing libc on LoongArch-64
* Wed Mar 16 2022 Dirk Müller <dmueller@suse.com>
- add procps dependency for sysctl
* Mon Dec 20 2021 Dirk Müller <dmueller@suse.com>
- update to 2.5.0:
  * split checksec into multiple files for easier maintenance and debugging
  * remove space between options and only support `=` until refactor can happen
  * update License.txt to include BSD license
  * Check journalctl -k for NX protection
  * improve debug formatting
  * Fix shellcheck warnings and style issues
  * Make --dir option follow symlinks
* Wed Jun  9 2021 Dirk Müller <dmueller@suse.com>
- add missing gawk dependency
* Thu Mar 25 2021 Dirk Müller <dmueller@suse.com>
- Initial package (derived from Fedora spec)
